.. currentmodule:: pynsitu

What's New
==========

.. _whats-new.0.0.2:

v0.0.2 (September 2024)
----------------------

- Arbitrary milestone, drops geojsoncontour.
  By `Aurelien Ponte <https://github.com/apatlpo>`_.


.. _whats-new.0.0.1:

v0.0.1 (Sometime between 2022 and 2024)
----------------------

- Strengthened unit testing and documentation, very much work in progress
  By `Aurelien Ponte <https://github.com/apatlpo>`_.


.. _whats-new.0.0.0:

v0.0.0 (January 2022)
----------------------

- Init repository.
  By `Aurelien Ponte <https://github.com/apatlpo>`_.
